CreateChargeResponse class

Response model for charge creation

Constructors

CreateChargeResponse({required String invoiceId, String? paymentUrl, required String status, String? message})
CreateChargeResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
invoiceId String
Transaction/Invoice ID
final
message String?
Error message if any
final
paymentUrl String?
Payment gateway URL to redirect user to
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
Status of charge creation
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited