PiprapayWebhookException class
Exception thrown when webhook validation fails
- Inheritance
-
- Object
- PiprapayException
- PiprapayWebhookException
Constructors
- PiprapayWebhookException({required String message, dynamic originalException, StackTrace? stackTrace})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
finalinherited
- originalException → dynamic
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace?
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited